@@ -69,6 +69,14 @@ from fds.analyticsapi.engines.model.frequency import Frequency
 from fds.analyticsapi.engines.model.frequency_root import FrequencyRoot
 from fds.analyticsapi.engines.model.group import Group
 from fds.analyticsapi.engines.model.group_root import GroupRoot
+from fds.analyticsapi.engines.model.linked_pa_template import LinkedPATemplate
+from fds.analyticsapi.engines.model.linked_pa_template_parameters import LinkedPATemplateParameters
+from fds.analyticsapi.engines.model.linked_pa_template_parameters_root import LinkedPATemplateParametersRoot
+from fds.analyticsapi.engines.model.linked_pa_template_root import LinkedPATemplateRoot
+from fds.analyticsapi.engines.model.linked_pa_template_summary import LinkedPATemplateSummary
+from fds.analyticsapi.engines.model.linked_pa_template_summary_root import LinkedPATemplateSummaryRoot
+from fds.analyticsapi.engines.model.linked_pa_template_update_parameters import LinkedPATemplateUpdateParameters
+from fds.analyticsapi.engines.model.linked_pa_template_update_parameters_root import LinkedPATemplateUpdateParametersRoot
 from fds.analyticsapi.engines.model.npo_optimization_parameters import NPOOptimizationParameters
 from fds.analyticsapi.engines.model.npo_optimization_parameters_root import NPOOptimizationParametersRoot
 from fds.analyticsapi.engines.model.npo_optimizer_strategy import NPOOptimizerStrategy
@@ -88,6 +96,7 @@ from fds.analyticsapi.engines.model.pa_calculation_group import PACalculationGro
 from fds.analyticsapi.engines.model.pa_calculation_parameters import PACalculationParameters
 from fds.analyticsapi.engines.model.pa_calculation_parameters_root import PACalculationParametersRoot
 from fds.analyticsapi.engines.model.pa_component import PAComponent
+from fds.analyticsapi.engines.model.pa_component_data import PAComponentData
 from fds.analyticsapi.engines.model.pa_component_root import PAComponentRoot
 from fds.analyticsapi.engines.model.pa_date_parameters import PADateParameters
 from fds.analyticsapi.engines.model.pa_identifier import PAIdentifier
@@ -96,23 +105,57 @@ from fds.analyticsapi.engines.model.pub_calculation_parameters import PubCalcula
 from fds.analyticsapi.engines.model.pub_calculation_parameters_root import PubCalculationParametersRoot
 from fds.analyticsapi.engines.model.pub_date_parameters import PubDateParameters
 from fds.analyticsapi.engines.model.pub_identifier import PubIdentifier
+from fds.analyticsapi.engines.model.quant_all_universal_screen_parameters import QuantAllUniversalScreenParameters
 from fds.analyticsapi.engines.model.quant_calculation_meta import QuantCalculationMeta
 from fds.analyticsapi.engines.model.quant_calculation_parameters import QuantCalculationParameters
 from fds.analyticsapi.engines.model.quant_calculation_parameters_root import QuantCalculationParametersRoot
+from fds.analyticsapi.engines.model.quant_date import QuantDate
 from fds.analyticsapi.engines.model.quant_date_list import QuantDateList
+from fds.analyticsapi.engines.model.quant_date_list_obsolete import QuantDateListObsolete
 from fds.analyticsapi.engines.model.quant_fds_date import QuantFdsDate
+from fds.analyticsapi.engines.model.quant_fds_date_obsolete import QuantFdsDateObsolete
+from fds.analyticsapi.engines.model.quant_formula import QuantFormula
 from fds.analyticsapi.engines.model.quant_fql_expression import QuantFqlExpression
+from fds.analyticsapi.engines.model.quant_fql_expression_obsolete import QuantFqlExpressionObsolete
 from fds.analyticsapi.engines.model.quant_identifier_universe import QuantIdentifierUniverse
+from fds.analyticsapi.engines.model.quant_identifier_universe_obsolete import QuantIdentifierUniverseObsolete
 from fds.analyticsapi.engines.model.quant_screening_expression import QuantScreeningExpression
+from fds.analyticsapi.engines.model.quant_screening_expression_obsolete import QuantScreeningExpressionObsolete
 from fds.analyticsapi.engines.model.quant_screening_expression_universe import QuantScreeningExpressionUniverse
+from fds.analyticsapi.engines.model.quant_screening_expression_universe_obsolete import QuantScreeningExpressionUniverseObsolete
 from fds.analyticsapi.engines.model.quant_universal_screen_parameter import QuantUniversalScreenParameter
+from fds.analyticsapi.engines.model.quant_universal_screen_parameter_obsolete import QuantUniversalScreenParameterObsolete
 from fds.analyticsapi.engines.model.quant_universal_screen_universe import QuantUniversalScreenUniverse
+from fds.analyticsapi.engines.model.quant_universal_screen_universe_obsolete import QuantUniversalScreenUniverseObsolete
+from fds.analyticsapi.engines.model.quant_universe import QuantUniverse
+from fds.analyticsapi.engines.model.return_type import ReturnType
+from fds.analyticsapi.engines.model.spar_accounts import SPARAccounts
+from fds.analyticsapi.engines.model.spar_accounts_root import SPARAccountsRoot
 from fds.analyticsapi.engines.model.spar_benchmark import SPARBenchmark
 from fds.analyticsapi.engines.model.spar_benchmark_root import SPARBenchmarkRoot
 from fds.analyticsapi.engines.model.spar_calculation_parameters import SPARCalculationParameters
 from fds.analyticsapi.engines.model.spar_calculation_parameters_root import SPARCalculationParametersRoot
 from fds.analyticsapi.engines.model.spar_date_parameters import SPARDateParameters
 from fds.analyticsapi.engines.model.spar_identifier import SPARIdentifier
+from fds.analyticsapi.engines.model.template_content_types import TemplateContentTypes
+from fds.analyticsapi.engines.model.templated_pa_component_parameters import TemplatedPAComponentParameters
+from fds.analyticsapi.engines.model.templated_pa_component_parameters_root import TemplatedPAComponentParametersRoot
+from fds.analyticsapi.engines.model.templated_pa_component_summary import TemplatedPAComponentSummary
+from fds.analyticsapi.engines.model.templated_pa_component_summary_root import TemplatedPAComponentSummaryRoot
+from fds.analyticsapi.engines.model.templated_pa_component_update_parameters import TemplatedPAComponentUpdateParameters
+from fds.analyticsapi.engines.model.templated_pa_component_update_parameters_root import TemplatedPAComponentUpdateParametersRoot
+from fds.analyticsapi.engines.model.unlinked_pa_template import UnlinkedPATemplate
+from fds.analyticsapi.engines.model.unlinked_pa_template_category_and_type import UnlinkedPATemplateCategoryAndType
+from fds.analyticsapi.engines.model.unlinked_pa_template_category_and_type_details import UnlinkedPATemplateCategoryAndTypeDetails
+from fds.analyticsapi.engines.model.unlinked_pa_template_category_and_type_details_root import UnlinkedPATemplateCategoryAndTypeDetailsRoot
+from fds.analyticsapi.engines.model.unlinked_pa_template_category_and_type_root import UnlinkedPATemplateCategoryAndTypeRoot
+from fds.analyticsapi.engines.model.unlinked_pa_template_parameters import UnlinkedPATemplateParameters
+from fds.analyticsapi.engines.model.unlinked_pa_template_parameters_root import UnlinkedPATemplateParametersRoot
+from fds.analyticsapi.engines.model.unlinked_pa_template_root import UnlinkedPATemplateRoot
+from fds.analyticsapi.engines.model.unlinked_pa_template_summary import UnlinkedPATemplateSummary
+from fds.analyticsapi.engines.model.unlinked_pa_template_summary_root import UnlinkedPATemplateSummaryRoot
+from fds.analyticsapi.engines.model.unlinked_pa_template_update_parameters import UnlinkedPATemplateUpdateParameters
+from fds.analyticsapi.engines.model.unlinked_pa_template_update_parameters_root import UnlinkedPATemplateUpdateParametersRoot
 from fds.analyticsapi.engines.model.vault_calculation_parameters import VaultCalculationParameters
 from fds.analyticsapi.engines.model.vault_calculation_parameters_root import VaultCalculationParametersRoot
 from fds.analyticsapi.engines.model.vault_component import VaultComponent
